cache library
Classes
- MemoryLabelCache
-
This is a memory-only implementation of the
TileBitmapCache. It stores the bitmaps in memory. We use a factory and remember all active instances. This way we can easily purge caches if needed.
TileBitmapCache. It stores the bitmaps in memory.
We use a factory and remember all active instances. This way we can easily purge caches if needed.