MemoryLabelCache class

This is a memory-only implementation of the TileBitmapCache. It stores the bitmaps in memory. We use a factory and remember all active instances. This way we can easily purge caches if needed.

Constructors

MemoryLabelCache.create()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
get(Tile tile) → RenderInfoCollection?
getOrProduce(Tile leftUpper, Tile rightLower, Future<RenderInfoCollection> producer(Tile)) → Future<RenderInfoCollection>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
purgeAll() → void
purgeByBoundary(BoundingBox boundingBox) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

purgeAllCaches() → void
purgeCachesByBoundary(BoundingBox boundingBox) → void