ContextMenuInfo class

///////////////////////////////////////////////////////////////////////////

Constructors

ContextMenuInfo({required MapModel mapModel, required double halfScreenWidth, required double halfScreenHeight, required double diffX, required double diffY, required TapEvent event})

Properties

diffX → double
final
diffY → double
final
event → TapEvent
final
halfScreenHeight → double
final
halfScreenWidth → double
final
hashCode → int
The hash code for this object.
no setterinherited
latitude → double
no setter
latLong → ILatLong
no setter
longitude → double
no setter
mapModel → MapModel
final
projection → PixelProjection
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited