DefaultHandler class

Implementers

Constructors

DefaultHandler({required int longPressDuration, required MapModel mapModel})

Properties

hashCode → int
The hash code for this object.
no setterinherited
longPressDuration → int
final
mapModel → MapModel
final
maxDistance → int
The maximum distance in pixels which the curser is allowed to move between tapDown and tapUp.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
getter/setter pair
startOffset ↔ Offset?
getter/setter pair
startPosition ↔ MapPosition?
getter/setter pair

Methods

activeTimer() → bool
cancelTimer() → void
createEvent(Offset offset) → TapEvent
hasMoved(Offset offset) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPointerCancel(int pointerId, Offset offset, Map<int, Offset> pointers) → void
onPointerDown(MapPosition position, int pointerId, Offset offset, Map<int, Offset> pointers) → void
onPointerMove(int pointerId, Offset offset, Map<int, Offset> pointers) → void
onPointerUp(int pointerId, Offset offset, Map<int, Offset> pointers) → void
onTimeout() → void
setSize(Size size) → void
startTimer() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited