LongTapHandler class

Inheritance

Constructors

LongTapHandler({required int longPressDuration, required MapModel mapModel})

Properties

hashCode → int
The hash code for this object.
no setterinherited
longPressDuration → int
finalinherited
mapModel → MapModel
finalinherited
maxDistance → int
The maximum distance in pixels which the curser is allowed to move between tapDown and tapUp.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size
getter/setter pairinherited
startOffset ↔ Offset?
getter/setter pairinherited
startPosition ↔ MapPosition?
getter/setter pairinherited

Methods

activeTimer() → bool
inherited
cancelTimer() → void
inherited
createEvent(Offset offset) → TapEvent
inherited
hasMoved(Offset offset) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onPointerCancel(int pointerId, Offset offset, Map<int, Offset> pointers) → void
inherited
onPointerDown(MapPosition position, int pointerId, Offset offset, Map<int, Offset> pointers) → void
override
onPointerMove(int pointerId, Offset offset, Map<int, Offset> pointers) → void
override
onPointerUp(int pointerId, Offset offset, Map<int, Offset> pointers) → void
override
onTimeout() → void
override
setSize(Size size) → void
inherited
startTimer() → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited