DragNdropEvent class

///////////////////////////////////////////////////////////////////////////

Inheritance

Constructors

DragNdropEvent({required double latitude, required double longitude, required PixelProjection projection, required Mappoint mappoint, required DragNdropEventType type})

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
The latitude of this point in degrees.
finalinherited
latLong → LatLong
no setterinherited
longitude → double
The longitude of this point in degrees.
finalinherited
mappoint → Mappoint
The point of the event in absolute mappixels
finalinherited
projection → PixelProjection
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → DragNdropEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited