MapModel class

Inheritance

Constructors

MapModel({required Renderer renderer, ZoomlevelRange zoomlevelRange = const ZoomlevelRange.standard()})

Properties

doubleTapStream → Stream<TapEvent?>
A stream which triggers an event if the user double-taps at the map. Sending a null value down the stream means that the listener is not entitled to handle the event anymore. This is currently being used to hide the context menu.
no setter
dragNdropStream → Stream<DragNdropEvent>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
labelRenderers → Iterable<Renderer>
no setter
lastPosition → MapPosition?
no setter
longTapStream → Stream<TapEvent?>
A stream which triggers an event if the user long taps at the map. Sending a null value down the stream means that the listener is not entitled to handle the event anymore. This is currently being used to hide the context menu.
no setter
manualMoveStream → Stream<Object>
A stream which triggers an event if the user starts to move the map. This can be used to switch off automatic movements
no setter
positionStream → Stream<MapPosition>
no setter
renderChangedStream → Stream<RenderChangedEvent>
Listens to RenderChangedEvent events. @see RenderChangedEvent
no setter
renderers → List<Renderer>
no setter
rotationDeg → double
no setter
rotationNotifier → ValueNotifier<double>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tapStream → Stream<TapEvent?>
A stream which triggers an event if the user taps at the map. Sending a null value down the stream means that the listener is not entitled to handle the event anymore. This is currently being used to hide the context menu.
no setter
zoomlevelRange → ZoomlevelRange
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addRenderer(Renderer renderer) → void
dispose() → Future<void>
Discards any resources used by the object.
override
doubleTap(TapEvent? event) → void
dragNdrop(DragNdropEvent event) → void
getTappedMarkers(TapEvent event) → List<Marker>
indoorLevelDown() → void
indoorLevelUp() → void
longTap(TapEvent? event) → void
manualMove(Object object) → void
moveCenter(double dx, double dy) → void
Moves the center of the map in relative pixel coordinates.
moveRotateTo(double latitude, double longitude, double rotation) → void
Moves to a new latitude and longitude and rotates to a specific angle in degrees clockwise.
moveTo(double latitude, double longitude) → void
Moves to a new latitude and longitude. There must already be a position set.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
registerMarkerDatastore(MarkerDatastore datastore) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
renderChanged(RenderChangedEvent event) → void
Triggers a RenderChangedEvent event. @see RenderChangedEvent
rotateBy(double rotationDelta) → void
rotateTo(double rotation) → void
scaleAround(Offset? focalPoint, double scale) → void
Sets the scale around a focal point.
setCenter(double x, double y) → void
Sets the center of the mapmodel to the given coordinates in mappixel. There must already be a position set.
setIndoorLevel(int level) → void
setPosition(MapPosition position) → void
tap(TapEvent? event) → void
sets or clears a tap event. Clearing a tap event usually means that the context menu should not be shown anymore
toString() → String
A string representation of this object.
inherited
unregisterMarkerDatastore(MarkerDatastore datastore) → void
zoomIn() → void
zoomInAround(double latitude, double longitude) → void
zoomOut() → void
zoomTo(int zoomLevel) → void
zoomToAround(double latitude, double longitude, int zoomLevel) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited