MapPosition class

Immutable position of the map

Constructors

MapPosition(double _latitude, double _longitude, int zoomlevel, [int indoorLevel = 0, double _rotation = 0])

Properties

focalPoint → Offset?
The focal point. Used when pinch-and-zoom to know the center of the zoom
final
hashCode → int
The hash code for this object.
no setterinherited
indoorLevel → int
The current indoorLevel
final
latitude → double
The latitude of the center of the widget
no setter
longitude → double
The longitude of the center of the widget
no setter
projection → PixelProjection
no setter
rotation → double
Returns the rotation of the map in degrees clockwise
no setter
rotationRadian → double
Returns the rotation in radians
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
zoomlevel → int
The current zoomLevel
final

Methods

getCenter() → Mappoint
Returns the center of the map in absolute mappixels
getLatLong() → ILatLong
indoorLevelDown() → MapPosition
Decreases the indoor level by 1.
indoorLevelUp() → MapPosition
Increases the indoor level by 1.
moveCenter(double dx, double dy) → MapPosition
Moves the center of the map in relative pixel coordinates.
moveRotateTo(double latitude, double longitude, double rotation) → MapPosition
Moves to a new latitude and longitude and rotates to a specific angle in degrees clockwise.
moveTo(double latitude, double longitude) → MapPosition
Moves to a new latitude and longitude.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateBy(double rotationDelta) → MapPosition
Rotates by a delta angle in degrees clockwise.
rotateTo(double rotation) → MapPosition
Rotates to a specific angle in degrees clockwise.
scaleAround(Offset? focalPoint, double scale) → MapPosition
Sets the scale around a focal point.
setCenter(double x, double y) → MapPosition
The center of the map in absolute pixel coordinates.
toString() → String
A string representation of this object.
override
withIndoorLevel(int level) → MapPosition
Sets a specific indoor level.
zoomIn() → MapPosition
zoomInAround(double latitude, double longitude) → MapPosition
Zooms in around a specific latitude and longitude point.
zoomOut() → MapPosition
Zooms out from the current position.
zoomTo(int newZoomLevel) → MapPosition
Zooms to a specific zoom level.
zoomToAround(double latitude, double longitude, int newZoomLevel) → MapPosition
Zooms to a specific level around a given latitude and longitude.

Operators

operator ==(Object other) → bool
The equality operator.
inherited