RenderChangedEvent class

/////////////////////////////////////////////////////////////////////////// Event which is triggered when a part of the render area (hence a part of the map) has been changed so that a rerender is required. This forces eventual caches to revalidate and redraw the screen if the currently shown area is affected. This may occur if a MultimapDatastore adds or removes datastores or if the user changes the desired StyleMenuLayer.

Constructors

RenderChangedEvent(BoundingBox boundingBox)

Properties

boundingBox → BoundingBox
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited