TapEvent class

////////////////////////////////////////////////////////////////////////// Event which is triggered when the user taps at the map

Implementers

Constructors

TapEvent({required double latitude, required double longitude, required PixelProjection projection, required Mappoint mappoint})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
latitude → double
The latitude of this point in degrees.
final
latLong → LatLong
no setter
longitude → double
The longitude of this point in degrees.
final
mappoint → Mappoint
The point of the event in absolute mappixels
final
projection → PixelProjection
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited