DefaultMarkerDatastore<T> class

Inheritance

Constructors

DefaultMarkerDatastore()

Properties

disposed → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addMarker(Marker<T> marker) → void
Adds a new marker.
override
addMarkers(Iterable<Marker<T>> markers) → void
Adds multiple markers to the datastore in a batch operation.
override
askChangeBoundingBox(int zoomlevel, BoundingBox boundingBox) → void
Called when the map view moves to a new area at the same zoom level.
override
askChangeZoomlevel(int zoomlevel, BoundingBox boundingBox, PixelProjection projection) → void
Called when the map zoom level changes.
override
askRetrieveMarkersToPaint() → Iterable<Marker<T>>
Returns the markers that should be rendered on the current screen.
override
clearMarkers() → void
Do not forget to call setRepaint()
override
dispose() → void
Disposes of the datastore and releases any held resources.
override
getAllMarkers() → List<Marker<T>>
getMarkerByKey(T key) → Marker<T>?
getTappedMarkers(TapEvent event) → List<Marker<T>>
Returns markers that intersect with the given tap event area.
override
markerChanged(Marker<T> marker) → void
Notifies the datastore that a marker's properties have changed.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
reinitOneMarker(_CurrentMarkers<T> currentMarkers, Marker<T> marker) → Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeMarker(Marker<T> marker) → void
Do not forget to call setRepaint()
override
removeMarkerByKey(T key) → void
requestRepaint() → void
Requests a repaint of the marker overlay.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited