A view to display the labels. The view updates itself whenever the MapPosition changes and new labels are available.
Labels are drawn separately so they keep orientation.
Default view for many features of mapsforge. If you want to add or remove these features, just copy the Stack to your own application and modify it
accordingly.
///////////////////////////////////////////////////////////////////////////
Event which is triggered when a part of the render area (hence a part of the map) has been changed so that a rerender is required.
This forces eventual caches to revalidate and redraw the screen if the
currently shown area is affected.
This may occur if a MultimapDatastore adds or removes datastores or if the user changes the desired StyleMenuLayer.