StyleMenuBar class

Stateful widget to display a vertical style menu bar.

This is intentionally similar in interaction and appearance to IndoorLevelBar, but it shows the user-visible layers of a Mapsforge render theme stylemenu.

Inheritance

Constructors

StyleMenuBar({Key? key, required StyleMenu styleMenu, required OnStyleChange onChange, double width = 140, double itemHeight = 45, int maxVisibleItems = 5, Color fillColor = Colors.white, Color activeColor = Colors.blue, double elevation = 2, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(20)), String? initialLayerId, String? lang})
const

Properties

activeColor Color
final
borderRadius BorderRadius
final
elevation double
final
fillColor Color
final
hashCode int
The hash code for this object.
no setterinherited
initialLayerId String?
Optional initial layer id.
final
itemHeight double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lang String?
Optional desired language for layer names.
final
maxVisibleItems int
final
onChange OnStyleChange
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleMenu → StyleMenu
final
width double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StyleMenuBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited